Crate gadget_blueprint_proc_macro

Crate gadget_blueprint_proc_macro 

Blueprint Macros

Macros

load_abi
A procedural macro that outputs the JsonAbi for the given file path.

Attribute Macros

benchmark
A procedural macro that annotates a function as a benchmark hook, mainly used during the benchmarking phase.
job
A procedural macro that annotates a function as a job.
main
A procedural macro that annotates a function as a main function for the blueprint.
registration_hook
A procedural macro that annotates a function as a registration hook, mainly used for the metadata in the blueprint.json.
report
Creates a misbehavior report handler for the given function.
request_hook
A procedural macro that annotates a function as a request hook, mainly used for the metadata in the blueprint.json.